@@ -4,20 +4,23 @@
 from __future__ import (absolute_import, division,
                         print_function, unicode_literals)
 # from builtins import *
+import sys
 import os
 import base64
-import time
+import glob
 import hashlib
 import requests
 import rich
 import json
 import xml.etree.ElementTree as ET
+from xml.etree import ElementTree
+from xml.dom import minidom
 from loguru import logger
 from urllib.request import urlopen
 from rich import console
 from eos_downloader.download import DownloadProgressBar
 from eos_downloader.data import DATA_MAPPING
-from eos_downloader import ARISTA_GET_SESSION, ARISTA_SOFTWARE_FOLDER_TREE, ARISTA_DOWNLOAD_URL, MSG_TOKEN_EXPIRED
+from eos_downloader import ARISTA_GET_SESSION, ARISTA_SOFTWARE_FOLDER_TREE, ARISTA_DOWNLOAD_URL, MSG_TOKEN_EXPIRED, MSG_INVALID_DATA, EVE_QEMU_FOLDER_PATH
 from tqdm import tqdm
 
 console = rich.get_console()
@@ -53,13 +56,9 @@ class ObjectDownloader():
         self.session_id = None
         self.filename = self._build_filename()
         self.hash_method = hash_method
+        # Logging
+        logger.debug(f'Filename built by _build_filename is {self.filename}')
 
-    def __rpr__(self):
-        return {
-            'software': self.software,
-            'image': self.image,
-            'version': self.version,
-        }
 
     def __str__(self):
         return self.software + ' - ' + self.image + ' - ' + self.version
@@ -88,9 +87,9 @@ class ObjectDownloader():
         """
         if self.software in DATA_MAPPING:
             if self.image in DATA_MAPPING[self.software]:
-                return DATA_MAPPING[self.software][self.image]['prepend'] + "-" + self.version + DATA_MAPPING[self.software][self.image]['extension']
+                return f"{DATA_MAPPING[self.software][self.image]['prepend']}-{self.version}{DATA_MAPPING[self.software][self.image]['extension']}"
             else:
-                return DATA_MAPPING[self.software]['default']['prepend'] + "-" + self.version + DATA_MAPPING[self.software]['default']['extension']
+                return f"{DATA_MAPPING[self.software]['default']['prepend']}-{self.version}{DATA_MAPPING[self.software]['default']['extension']}"
         return None
 
     def _parse_xml(self, root_xml: ET.ElementTree, xpath: str, search_file: str):
@@ -224,8 +223,13 @@ class ObjectDownloader():
             self.authenticate()
         jsonpost = {'sessionCode': self.session_id}
         result = requests.post(ARISTA_SOFTWARE_FOLDER_TREE, data=json.dumps(jsonpost))
-        folder_tree = (result.json()["data"]["xml"])
-        return ET.ElementTree(ET.fromstring(folder_tree))
+        try:
+            folder_tree = (result.json()["data"]["xml"])
+            return ET.ElementTree(ET.fromstring(folder_tree))
+        except KeyError as error:
+            logger.error(MSG_INVALID_DATA)
+            console.print(f'❌  {MSG_INVALID_DATA}', style="bold red")
+            sys.exit(1)
 
     def _get_remote_filepath(self):
         """
@@ -361,21 +365,24 @@ class ObjectDownloader():
         result = requests.post(session_code_url, data=json.dumps(jsonpost))
 
         if result.json()["status"]["message"] == 'Access token expired':
-            console.print('❌  ', MSG_TOKEN_EXPIRED, style="bold green")
+            console.print(f'❌  {MSG_TOKEN_EXPIRED}', style="bold red")
             logger.error(MSG_TOKEN_EXPIRED)
             return False
         elif result.json()["status"]["message"] == 'Invalid access token':
             logger.error(MSG_TOKEN_EXPIRED)
-            console.print('❌  ', MSG_TOKEN_EXPIRED, style="bold green")
+            console.print(f'❌  {MSG_TOKEN_EXPIRED}', style="bold red")
             return False
 
-        if 'data' in result.json():
-            self.session_id = (result.json()["data"]["session_code"])
-            logger.info('Authenticated on arista.com')
-            console.print('✅ Authenticated on arista.com')
-            return True
-        logger.debug('{}'.format(result.json()))
-        return False
+        try:
+            if 'data' in result.json():
+                self.session_id = (result.json()["data"]["session_code"])
+                logger.info('Authenticated on arista.com')
+                console.print('✅ Authenticated on arista.com')
+                return True
+            logger.debug('{}'.format(result.json()))
+            return False
+        except KeyError as error_arista:
+            sys.exit(1)
 
     def download_local(self, file_path: str, checksum: bool = False):
         """
@@ -474,3 +481,8 @@ class ObjectDownloader():
         logger.info(f'Importing image {self.filename} to {docker_image}')
         console.print(f'🚀 Importing image {self.filename} to {docker_image}')
         os.system(f'$(which docker) import {self.filename} {docker_image}')
+        for filename in glob.glob(f'{self.filename}*'):
+            try:
+                os.remove(filename)
+            except FileNotFoundError:
+                console.print(f'File not found: {filename}')
